package com.inspect.metadata.eqpbook.service.impl;

import com.inspect.metadata.eqpbook.domain.BasedataEqpBookModel;
import com.inspect.metadata.eqpbook.mapper.BasedataEqpBookModelMapper;
import com.inspect.metadata.eqpbook.service.IBasedataEqpBookModelService;
import com.inspect.base.core.utils.DateUtils;
import java.util.List;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;

@Service
public class BasedataEqpBookModelServiceImpl implements IBasedataEqpBookModelService {
   @Resource
   private BasedataEqpBookModelMapper basedataEqpbookModelMapper;

   public BasedataEqpBookModel selectBasedataEqpBookModelByEqpBookModelId(String eqpbookModelId) {
      return this.basedataEqpbookModelMapper.selectBasedataEqpBookModelByEqpBookModelId(eqpbookModelId);
   }

   public List<BasedataEqpBookModel> selectBasedataEqpBookModelList(BasedataEqpBookModel basedataEqpbookModel) {
      return this.basedataEqpbookModelMapper.selectBasedataEqpBookModelList(basedataEqpbookModel);
   }

   public int insertBasedataEqpBookModel(BasedataEqpBookModel basedataEqpbookModel) {
      basedataEqpbookModel.setCreateTime(DateUtils.getNowDate());
      return this.basedataEqpbookModelMapper.insertBasedataEqpBookModel(basedataEqpbookModel);
   }

   public int updateBasedataEqpBookModel(BasedataEqpBookModel basedataEqpbookModel) {
      basedataEqpbookModel.setUpdateTime(DateUtils.getNowDate());
      return this.basedataEqpbookModelMapper.updateBasedataEqpBookModel(basedataEqpbookModel);
   }

   public int deleteBasedataEqpBookModelByEqpBookModelIds(String[] eqpbookModelIds) {
      return this.basedataEqpbookModelMapper.deleteBasedataEqpBookModelByEqpBookModelIds(eqpbookModelIds);
   }

   public int deleteBasedataEqpBookModelByEqpBookModelId(String eqpbookModelId) {
      return this.basedataEqpbookModelMapper.deleteBasedataEqpBookModelByEqpBookModelId(eqpbookModelId);
   }
}
